@@ -116,17 +116,37 @@ function sitebuilder_uvt_process_page(&$variables, $hook) {
 }
 
 /**
- * Create themed owner field.
+ * Implements mediamosa_ck_views_field_text_mediafiles().
  */
-function sitebuilder_uvt_theme_mediamosa_ck_views_theme_owner($variables) {
-  if (module_exists('surfconext')) {
-    $u = user_load($variables['uid']);
-    if (isset($u->display_name) && isset($u->display_name['und'][0]['value'])) {
-      return $u->display_name['und'][0]['value'];
-    }
-    else {
-      return '-';
-    }
+function sitebuilder_uvt_mediamosa_ck_views_theme_asset_mediafiles($variables) {
+  $output = array();
+
+  if (empty($variables['mediafiles'])) {
+    return t('There are no other formats available');
   }
-  theme_mediamosa_ck_views_theme_owner($variables);
+
+  $filelist = array();
+  // Loop.
+  foreach ($variables['mediafiles'] as $mediafile) {
+    // Skip doubles.
+    if (isset($filelist[$mediafile['filename']])) {
+      continue;
+    }
+    $filelist[$mediafile['filename']] = $mediafile['filename'];
+
+    if (empty($mediafile['metadata']['container_type'])) {
+      // Not analysed.
+      continue;
+    }
+
+    // Build the link.
+    $path = strtr($variables['asset_path'], array('[asset_id]' => $mediafile['asset_id'], '[mediafile_id]' => $mediafile['mediafile_id']));
+
+    // Get filename.
+    $output[] = '<li>';
+    $output[] = empty($mediafile['filename']) ? t('No filename present') : (l(trim($mediafile['filename']), $path));
+    $output[] = '</li>';
+  }
+
+  return empty($output) ? '' : '<ul>' . implode('', $output) . '</ul>';
 }
