@@ -29,7 +29,7 @@
     <?php print $fields['still_url']->content; ?>
   <?php else: ?>
 <?php print l(theme('image', array('path' => drupal_get_path('theme', 'sitebuilder_uvt') . '/images/notgranted-thumb.png', 'width' => '220px',
-  'height' => '124px', 'alt' => t("You don't have the right permissions to access this video"))), 'asset/detail/' . $fields['asset_id']->raw, array('html' => TRUE, 'attributes' => array('class' => 'views-field-still-url'))); ?>
+  'height' => '124px', 'alt' => t("You don't have the right permissions to access this media"))), 'asset/detail/' . $fields['asset_id']->raw, array('html' => TRUE, 'attributes' => array('class' => 'views-field-still-url'))); ?>
   <?php endif; ?>
 <?php endif; ?>
 
